<?php
/**
 * WPL_CronActions
 *
 * This class contains action hooks that are usually trigger via wp_cron()
 * 
 */

class WPL_CronActions extends WPL_Core {
	
	var $lockfile;

	public function __construct() {
		parent::__construct();
		
		// add cron handler
		add_action('wplister_update_auctions', array( &$this, 'cron_update_auctions' ) );

		## BEGIN PRO ##

		// add custom cron schedules
		add_filter( 'cron_schedules', array( &$this, 'cron_add_custom_schedules' ) );
 
 		// handle external cron calls
		add_action('wp_ajax_wplister_run_scheduled_tasks', array( &$this, 'cron_update_auctions' ) );
		add_action('wp_ajax_nopriv_wplister_run_scheduled_tasks', array( &$this, 'cron_update_auctions' ) );

		## END PRO ##

	}

	
	// update auctions - called by wp_cron if activated
	public function cron_update_auctions() {
        $this->logger->info("WP-CRON: cron_update_auctions()");

        // check if this is a staging site
        if ( $this->isStagingSite() ) {
	        $this->logger->info("WP-CRON: staging site detected! terminating execution...");
			self::updateOption( 'cron_auctions', '' );
			self::updateOption( 'create_orders', '' );
        	return;
        }

        // check if update is already running
        if ( ! $this->checkLock() ) {
	        $this->logger->error("WP-CRON: already running! terminating execution...");
        	return;
        }

		$this->initEC();
		
		// decide if the old transactions update or the new orders update mode is to be used
		$mode = get_option( 'wplister_ebay_update_mode', 'order' );
		if ( $mode == 'order' ) {
			$this->EC->updateEbayOrders(); // new
		} else {
			$this->EC->loadTransactions(); // old
		}

		// update ended items and process relist schedule
		$this->EC->updateListings(); 

		// clean up
		$this->EC->closeEbay();
		$this->removeLock();

		// store timestamp
		self::updateOption( 'cron_last_run', time() );

        $this->logger->info("WP-CRON: cron_update_auctions() finished");
	} // cron_update_auctions()

	public function checkLock() {

		// get full path to lockfile
		$uploads        = wp_upload_dir();
		$lockfile       = $uploads['basedir'] . '/' . 'wplister_sync.lock';
		$this->lockfile = $lockfile;

		// skip locking if lockfile is not writeable
		if ( ! is_writable( $lockfile ) && ! is_writable( dirname( $lockfile ) ) ) {
	        $this->logger->error("lockfile not writable: ".$lockfile);
	        return true;
		}

		// create lockfile if it doesn't exist
		if ( ! file_exists( $lockfile ) ) {
			$ts = time();
			file_put_contents( $lockfile, $ts );
	        $this->logger->info("lockfile created at TS $ts: ".$lockfile);
	        return true;
		}

		// lockfile exists - check TS
		$ts = (int) file_get_contents($lockfile); 

		// check if TS is outdated (after 10min.)
		if ( $ts < ( time() - 600 ) ) { 
	        $this->logger->info("stale lockfile found for TS ".$ts.' - '.human_time_diff( $ts ).' ago' );

	        // update lockfile 
			$ts = time();
			file_put_contents( $lockfile, $ts ); 
	        
	        $this->logger->info("lockfile updated for TS $ts: ".$lockfile);
	        return true;
		} else { 
			// process is still alive - can not run twice
	        $this->logger->info("SKIP CRON - sync already running with TS ".$ts.' - '.human_time_diff( $ts ).' ago' );
			return false; 
		} 

		return true;
	} // checkLock()

	public function removeLock() {
		if ( file_exists( $this->lockfile ) ) {
			unlink( $this->lockfile );
	        $this->logger->info("lockfile was removed: ".$this->lockfile);
		}
	}

	## BEGIN PRO ##
	public function cron_add_custom_schedules( $schedules ) {
		$schedules['fifteen_min'] = array(
			'interval' => 60 * 15,
			'display' => 'Once every fifteen minutes'
		);
		$schedules['thirty_min'] = array(
			'interval' => 60 * 30,
			'display' => 'Once every thirty minutes'
		);
		return $schedules;
	}
	## END PRO ##	


} // class WPL_CronActions

$WPL_CronActions = new WPL_CronActions();
